
--
-- Name: film; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE film (
    id integer NOT NULL,
    titre character varying(255) NOT NULL,
    annee integer NOT NULL
);


--
-- Name: film_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE film_seq
    START WITH 1
    INCREMENT BY 1
    NOMINVALUE
    NOMAXVALUE;


--
-- Name: joue_dans; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE joue_dans (
    film integer NOT NULL,
    acteur integer NOT NULL,
    personnage varchar2(255) NOT NULL,
    star integer CHECK(star in (0,1))
);


--
-- Name: personne; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE personne (
    id integer NOT NULL,
    nom varchar2(255) NOT NULL,
    datenaissance date
);


--
-- Name: produit; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE produit (
    societe varchar2(255) NOT NULL,
    pays varchar2(255) NOT NULL,
    film integer NOT NULL
);


--
-- Name: realise; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE realise (
    realisateur integer NOT NULL,
    film integer NOT NULL
);


--
-- Name: societe; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE societe (
    nom varchar2(255) NOT NULL,
    pays varchar2(255) NOT NULL,
    website varchar2(255)
);


--
-- Name: film_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE  film
    ADD CONSTRAINT film_pkey PRIMARY KEY (id);


--
-- Name: film_titre_annee_key; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE  film
    ADD CONSTRAINT film_titre_annee_key UNIQUE (titre, annee);


--
-- Name: joue_dans_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE  joue_dans
    ADD CONSTRAINT joue_dans_pkey PRIMARY KEY (film, acteur, personnage);


--
-- Name: personne_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE  personne
    ADD CONSTRAINT personne_pkey PRIMARY KEY (id);


--
-- Name: produit_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE  produit
    ADD CONSTRAINT produit_pkey PRIMARY KEY (societe, pays, film);


--
-- Name: realise_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE  realise
    ADD CONSTRAINT realise_pkey PRIMARY KEY (realisateur, film);


--
-- Name: societe_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE  societe
    ADD CONSTRAINT societe_pkey PRIMARY KEY (nom, pays);


--
-- Name: joue_dans_film_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE  joue_dans
    ADD CONSTRAINT joue_dans_film_fkey FOREIGN KEY (film) REFERENCES film(id);


--
-- Name: produit_film_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE  produit
    ADD CONSTRAINT produit_film_fkey FOREIGN KEY (film) REFERENCES film(id);


--
-- Name: produit_societe_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE  produit
    ADD CONSTRAINT produit_societe_fkey FOREIGN KEY (societe, pays) REFERENCES societe(nom, pays);


--
-- Name: realise_film_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE  realise
    ADD CONSTRAINT realise_film_fkey FOREIGN KEY (film) REFERENCES film(id);


--
-- Name: realise_realisateur_fkey; Type: FK CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE  realise
    ADD CONSTRAINT realise_realisateur_fkey FOREIGN KEY (realisateur) REFERENCES personne(id);


--
-- PostgreSQL database dump complete
--

